import React, { useEffect, useState } from "react";
import { useParams } from "react-router-dom";
import axios from "axios";
import styles from "./EditUserDetailsStyles.module.css";

const EditUserDetails = () => {
  const { personId } = useParams();
  const [personDetails, setPersonDetails] = useState(null); 
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);

  // I added these two useStates so we will be able to check for editing and deleting
  const [isEditing, setIsEditing] = useState(false);
  const [showDeleteConfirm, setShowDeleteConfirm] = useState(false);
  // const navigate = useNavigate();

  useEffect(() => {
    const fetchPersonDetails = async () => {
      setLoading(true);
      setError(null);

      try {
        const response = await axios.get(
          `${process.env.REACT_APP_API_URL}/person/fullInfo/${personId}`
        );
        setPersonDetails(response.data.person);
      } catch (err) {
        setError(
          err.response?.data?.message || "Failed to fetch user details."
        );
      } finally {
        setLoading(false);
      }
    };

    fetchPersonDetails();
  }, [personId]);

  const handleEdit = () => {
    setIsEditing(true);
  };

  const handleSave = async () => {
    try {
      await axios.put(
        `${process.env.REACT_APP_API_URL}/person/update/${personId}`,
        personDetails
      );
      setIsEditing(false);
      alert("User details updated successfully!");
    } catch (err) {
      alert("Failed to update user details.");
    }
  };

  const handleDelete = async () => {
    try {
      await axios.delete(`${process.env.REACT_APP_API_URL}/person/${personId}`);
      alert("User deleted successfully!");
      // navigate("/users");
    } catch (err) {
      alert("Failed to delete user.");
    }
  };

  if (loading) return <p>Loading user details...</p>;
  if (error) return <p className={styles.error}>{error}</p>;

  return (
    <div className={styles.container}>
      <h2>User Details</h2>
      <p><strong>Person ID:</strong> {personId}</p>
      <div className={styles.details}>

        <p>
          <strong>First Name:</strong>{" "}
          {isEditing ? (
            <input
              type="text"
              value={personDetails.personalInformation.firstName}
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  personalInformation: {
                    ...personDetails.personalInformation,
                    firstName: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.personalInformation.firstName
          )}
        </p>
        <p>
          <strong>Last Name:</strong>{" "}
          {isEditing ? (
            <input
              type="text"
              value={personDetails.personalInformation.lastName}
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  personalInformation: {
                    ...personDetails.personalInformation,
                    lastName: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.personalInformation.lastName
          )}
        </p>
        <p>
          <strong>Middle Name:</strong>{" "}
          {isEditing ? (
            <input
              type="text"
              value={personDetails.personalInformation.middleName || ""}
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  personalInformation: {
                    ...personDetails.personalInformation,
                    middleName: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.personalInformation.middleName || "N/A"
          )}
        </p>
        <p>
          <strong>Nick Name:</strong>{" "}
          {isEditing ? (
            <input
              type="text"
              value={personDetails.personalInformation.nickName || ""}
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  personalInformation: {
                    ...personDetails.personalInformation,
                    nickName: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.personalInformation.nickName || "N/A"
          )}
        </p>
        <p>
          <strong>Class Year:</strong>{" "}
          {isEditing ? (
            <input
              type="number"
              value={personDetails.personalInformation.classYear}
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  personalInformation: {
                    ...personDetails.personalInformation,
                    classYear: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.personalInformation.classYear
          )}
        </p>
        <p>
          <strong>Graduation Year:</strong>{" "}
          {isEditing ? (
            <input
              type="number"
              value={personDetails.personalInformation.gradYear}
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  personalInformation: {
                    ...personDetails.personalInformation,
                    gradYear: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.personalInformation.gradYear
          )}
        </p>
        <p>
          <strong>Gender:</strong>{" "}
          {isEditing ? (
            <input
              type="text"
              value={personDetails.personalInformation.gender}
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  personalInformation: {
                    ...personDetails.personalInformation,
                    gender: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.personalInformation.gender
          )}
        </p>
        <p>
          <strong>Tech Alumni Chapter:</strong>{" "}
          {isEditing ? (
            <input
              type="text"
              value={personDetails.personalInformation.techAlumniChapter}
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  personalInformation: {
                    ...personDetails.personalInformation,
                    techAlumniChapter: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.personalInformation.techAlumniChapter
          )}
        </p>

        {/* Degrees Section */}

        <p>
          <strong>Persons Degree ID:</strong>{" "}
          {isEditing ? (
            <input
              type="text"
              value={personDetails.degrees?.personId}
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  personalInformation: {
                    ...personDetails.personalInformation,
                    personId: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.personalInformation.firstName
          )}
        </p>

        <p>
          <strong>Degree Type:</strong>{" "}
          {isEditing ? (
            <input
              type="text"
              value={personDetails.degrees?.degreeType || ""} 
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  degrees: {
                    ...personDetails.degrees, 
                    degreeType: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.degrees?.degreeType || "N/A" 
          )}
        </p>

        <p>
          <strong>Degree Department:</strong>{" "}
          {isEditing ? (
            <input
              type="text"
              value={personDetails.degrees?.degreeDepartment || ""} // Fallback to empty string if undefined
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  degrees: {
                    ...personDetails.degrees, 
                    degreeDepartment: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.degrees?.degreeDepartment || "N/A" // Fallback to "N/A" if degreeDepartment is undefined
          )}
        </p>

        <p>
          <strong>Degree College:</strong>{" "}
          {isEditing ? (
            <input
              type="text"
              value={personDetails.degrees?.degreeCollege || ""} // Fallback to empty string if undefined
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  degrees: {
                    ...personDetails.degrees, 
                    degreeCollege: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.degrees?.degreeCollege || "N/A" // Fallback to "N/A" if degreeCollege is undefined
          )}
        </p>

        <p>
          <strong>Degree Year:</strong>{" "}
          {isEditing ? (
            <input
              type="number"
              value={personDetails.degrees?.degreeYear || ""} // Fallback to empty string if undefined
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  degrees: {
                    ...personDetails.degrees, 
                    degreeYear: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.degrees?.degreeYear || "N/A" // Fallback to "N/A" if degreeYear is undefined
          )}
        </p>

        <p>
          <strong>Degree Description:</strong>{" "}
          {isEditing ? (
            <input
              type="text"
              value={personDetails.degrees?.degreeDescription || ""} // Fallback to empty string if undefined
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  degrees: {
                    ...personDetails.degrees, 
                    degreeDescription: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.degrees?.degreeDescription || "N/A" // Fallback to "N/A" if degreeDescription is undefined
          )}
        </p>

          {/* Address Section */}
          <p>
            <strong>Address Type:</strong>{" "}
            {isEditing ? (
              <input
                type="text"
                value={personDetails.address?.addressType || ""} // Add fallback to avoid undefined error
                onChange={(e) =>
                  setPersonDetails({
                    ...personDetails,
                    address: {
                      ...personDetails.address,
                      addressType: e.target.value,
                    },
                  })
                }
              />
            ) : (
              personDetails.address?.addressType || "N/A" // Fallback to "N/A" if addressType is undefined
            )}
          </p>
          <p>
            <strong>Address Line 2:</strong>{" "}
            {isEditing ? (
              <input
                type="text"
                value={personDetails.address?.address2 || ""} // Fallback to "" if address2 is undefined
                onChange={(e) =>
                  setPersonDetails({
                    ...personDetails,
                    address: {
                      ...personDetails.address,
                      address2: e.target.value,
                    },
                  })
                }
              />
            ) : (
              personDetails.address?.address2 || "N/A" // Fallback to "N/A" if address2 is undefined
            )}
          </p>

          <p>
            <strong>City:</strong>{" "}
            {isEditing ? (
              <input
                type="text"
                value={personDetails.address.city} 
                onChange={(e) =>
                  setPersonDetails({
                    ...personDetails,
                    address: {
                      ...personDetails.address,
                      city: e.target.value,
                    },
                  })
                }
              />
            ) : (
              personDetails.address?.city || "N/A" // Fallback to "N/A" if city is undefined
            )}
          </p>

          <p>
            <strong>State:</strong>{" "}
            {isEditing ? (
              <input
                type="text"
                value={personDetails.address?.state || ""} // Fallback to "" if state is undefined
                onChange={(e) =>
                  setPersonDetails({
                    ...personDetails,
                    address: {
                      ...personDetails.address,
                      state: e.target.value,
                    },
                  })
                }
              />
            ) : (
              personDetails.address?.state || "N/A" // Fallback to "N/A" if state is undefined
            )}
          </p>

          <p>
            <strong>Country:</strong>{" "}
            {isEditing ? (
              <input
                type="text"
                value={personDetails.address?.country || ""} // Fallback to "" if country is undefined
                onChange={(e) =>
                  setPersonDetails({
                    ...personDetails,
                    address: {
                      ...personDetails.address,
                      country: e.target.value,
                    },
                  })
                }
              />
            ) : (
              personDetails.address?.country || "N/A" // Fallback to "N/A" if country is undefined
            )}
          </p>

          <p>
            <strong>Zip Code:</strong>{" "}
            {isEditing ? (
              <input
                type="text"
                value={personDetails.address?.zipCode || ""} // Fallback to "" if zipCode is undefined
                onChange={(e) =>
                  setPersonDetails({
                    ...personDetails,
                    address: {
                      ...personDetails.address,
                      zipCode: e.target.value,
                    },
                  })
                }
              />
            ) : (
              personDetails.address?.zipCode || "N/A" // Fallback to "N/A" if zipCode is undefined
            )}
          </p>

          <p>
            <strong>Preferred Address:</strong>{" "}
            {isEditing ? (
              <input
                type="text"
                value={personDetails.address?.preferredAddress || ""} // Fallback to "" if preferredAddress is undefined
                onChange={(e) =>
                  setPersonDetails({
                    ...personDetails,
                    address: {
                      ...personDetails.address,
                      preferredAddress: e.target.value,
                    },
                  })
                }
              />
            ) : (
              personDetails.address?.preferredAddress || "N/A" // Fallback to "N/A" if preferredAddress is undefined
            )}
          </p>

          
          <p>
          <strong>Contact Type:</strong>{" "}
          {isEditing ? (
            <input
              type="text"
              value={personDetails.contacts?.contactType || ""} // Fallback to "" if contactType is undefined
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  contacts: {
                    ...personDetails.contacts,
                    contactType: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.contacts?.contactType || "N/A" // Fallback to "N/A" if contactType is undefined
          )}
        </p>

        <p>
          <strong>Involvements:</strong>{" "}
          {isEditing ? (
            <input
              type="text"
              value={personDetails.involvements || ""} // Fallback to "" if contactType is undefined
              onChange={(e) =>
                setPersonDetails({
                  ...personDetails,
                  contacts: {
                    ...personDetails.involvements,
                    involvements: e.target.value,
                  },
                })
              }
            />
          ) : (
            personDetails.involvements || "N/A" // Fallback to "N/A" if contactType is undefined
          )}
        </p>

        {!isEditing ? (
          <button className={styles.editButton} onClick={handleEdit}>
            Edit
          </button>
        ) : (
          <button className={styles.saveButton} onClick={handleSave}>
            Save
          </button>
        )}
        <button
          className={styles.deleteButton}
          onClick={() => setShowDeleteConfirm(true)}
        >
          Delete
        </button>
      </div>

      {showDeleteConfirm && (
        <div className={styles.confirmPopup}>
          <p>Are you sure you want to delete this user?</p>
          <button className={styles.confirmButton} onClick={handleDelete}>
            Yes, Delete
          </button>
          <button
            className={styles.cancelButton}
            onClick={() => setShowDeleteConfirm(false)}
          >
            Cancel
          </button>
        </div>
      )}
    </div>
  );


  return (
    <div>
      <p>User details for user:</p>
      <p>personId</p>
    </div>
  );
};

export default EditUserDetails;
